<?php
/**
 * FiloBlu srl
 *
 * @category   FiloBlu
 * @package    FiloBlu_ReCaptcha
 * @copyright  FiloBlu srl (http://www.filoblu.com)
 *
 */

namespace FiloBlu\ReCaptcha\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;

class Data extends AbstractHelper
{
    const XML_PATH_GENERAL_ENABLED_FRONTEND = 'filoblu_recaptcha/general/enabled_frontend';
    const XML_PATH_GENERAL_PUBLIC_KEY = 'filoblu_recaptcha/general/website_key';
    const XML_PATH_GENERAL_PRIVATE_KEY = 'filoblu_recaptcha/general/secret_key';

    protected $scopeConfigInterface;
    protected $mathRandom;

    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfigInterface,
        \Magento\Framework\Math\Random $mathRandom
    ) {
        $this->scopeConfigInterface = $scopeConfigInterface;
        parent::__construct($context);
        $this->mathRandom = $mathRandom;
    }

    /**
     * Get error
     * @return string
     */
    public function getErrorDescription()
    {
        return __('Incorrect reCAPTCHA');
    }

    /**
     * Get google recaptcha website key
     * @return string
     */
    public function getPublicKey()
    {
        return trim($this->scopeConfigInterface->getValue(self::XML_PATH_GENERAL_PUBLIC_KEY));
    }

    /**
     * Get google recaptcha secret key
     * @return string
     */
    public function getPrivateKey()
    {
        return trim($this->scopeConfigInterface->getValue(self::XML_PATH_GENERAL_PRIVATE_KEY));
    }

    /**
     * Return true if enabled on frontend
     * @return bool
     */
    public function getEnabledFrontend()
    {
        if (!$this->getPrivateKey() || !$this->getPublicKey()) {
            return false;
        }

        return (bool) $this->scopeConfigInterface->getValue(self::XML_PATH_GENERAL_ENABLED_FRONTEND);
    }
}
